/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component("Central Component"),
                                         pNameLabel(0),
                                         pChooseButton(0)
{
    pNameLabel = new Label(L"Name Label", tr("Выберите файл..."));
    pNameLabel->setFont(Font(15.0000f, Font::bold));
    pNameLabel->setJustificationType(Justification::centred);
    pNameLabel->setEditable(false, false, false);
    pNameLabel->setColour(Label::textColourId, Colours::black);
    pNameLabel->setColour(Label::backgroundColourId, Colours::azure);
    pNameLabel->setColour(Label::outlineColourId, Colours::black);
    addAndMakeVisible(pNameLabel);

    pChooseButton = new TextButton(L"Choose Button");
    pChooseButton->setButtonText(tr("Выбрать..."));
    pChooseButton->addListener(this);
    addAndMakeVisible(pChooseButton);

    setSize (400, 150);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pNameLabel->setBounds(10, 10, getWidth() - 20, 25);
    pChooseButton->setBounds(proportionOfWidth(0.5000f) - ((150) / 2), proportionOfHeight(0.5000f) - ((25) / 2), 150, 25);
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    if(pButton == pChooseButton)
    {
        // Задаём в качестве стартовой директории для поиска файла папку "Документы" текущего пользователя
        File InitialFile;
        InitialFile = InitialFile.getSpecialLocation(File::userDocumentsDirectory);
        
        // В качестве фильтра поиска файлов задаём изображения PNG и JPG
        WildcardFileFilter ImageFileFilter("*.png;*.jpg", String::empty, tr("Файлы изображений"));
        
        // Создаём компонент для предварительного просмотра открываемых файлов
        ImagePreviewComponent ImageViewWidget;
        
        // Компонент для отображения списка файлов
        FileBrowserComponent FileBrowser(FileBrowserComponent::openMode | FileBrowserComponent::canSelectFiles, 
                                         InitialFile, & ImageFileFilter, & ImageViewWidget);
        
        // Диалог для отображения FileBrowser
        FileChooserDialogBox OpenFileDialog(tr("Открыть изображение"), 
                                            tr("Выберите файл изображения, который вы хотите открыть..."), 
                                            FileBrowser, false, Colours::azure);
        OpenFileDialog.setSize(600, 400);

        // Если пользователь выбрал файл...
        if(OpenFileDialog.show())
        {
            // открываем его
            InitialFile = FileBrowser.getSelectedFile(0);
        }

        pNameLabel->setText(InitialFile.getFileName(), false);
    }
}
//---------------------------------------------------------------------

